import { RootConstruct } from "constructs";
import { Manifest } from "./manifest";
import type { ISynthesisSession } from "./synthesizer";
import type { WorkflowProps } from "./workflow";
import { Workflow } from "./workflow";
/**
 * Configuration properties for setting up a `Project` instance.
 */
export interface ProjectProps {
    /**
     * Directory for storing synthesized workflow files.
     *
     * @default "./.github/workflows"
     */
    readonly outdir?: string;
    /**
     * Skips workflow validation if set to true.
     *
     * @default false
     */
    readonly skipValidation?: boolean;
    /**
     * Skips protection against workflow file diffs if set to true.
     *
     * @default false
     */
    readonly skipDiffProtection?: boolean;
    /**
     * Enables additional checks, such as version verification for external actions.
     *
     * @default false
     */
    readonly additionalChecks?: boolean;
    /**
     * Allows continuation on error annotations if set to true.
     *
     * @default false
     */
    readonly continueOnErrorAnnotations?: boolean;
}
/**
 * Represents a GitHub Actions project, managing workflows and their output.
 */
export declare class Project extends RootConstruct {
    readonly outdir: string;
    readonly skipValidation?: boolean;
    readonly skipDiffProtection?: boolean;
    readonly additionalChecks?: boolean;
    readonly continueOnErrorAnnotations?: boolean;
    readonly manifest: Manifest;
    constructor(props?: ProjectProps);
    /**
     * Adds a new workflow to the project.
     *
     * @param id - Identifier for the workflow.
     * @param props - Configuration properties for the workflow.
     * @returns The newly created `Workflow` instance.
     */
    addWorkflow(id: string, props: WorkflowProps): Workflow;
    /**
     * Main synthesis process that orchestrates the synthesis steps.
     */
    synth(): void;
    /**
     * Ensures the output directory exists before synthesis.
     */
    protected prepareOutputDir(): void;
    /**
     * Creates a synthesis session object with configuration for synthesis.
     *
     * @returns A configured `ISynthesisSession` object.
     */
    protected createSynthesisSession(): ISynthesisSession;
    /**
     * Synthesizes each workflow and applies additional checks if configured.
     *
     * @param workflows - Array of workflows to synthesize.
     * @param session - Synthesis session information.
     */
    protected synthesizeWorkflows(workflows: Workflow[], session: ISynthesisSession): void;
    /**
     * Handles any errors encountered during synthesis.
     *
     * @param error - The error encountered during synthesis.
     * @throws An error if validation fails or if another error type is encountered.
     */
    protected handleSynthesisError(error: unknown): void;
    /**
     * Finalizes the synthesis process, printing annotations and handling error annotations.
     */
    protected finalizeSynthesis(): void;
    /**
     * Prints annotations from a workflow manifest to the console.
     *
     * @param manifest - The `IManifest` object containing workflows and their annotations.
     * @param printStacktrace - Optional flag to print stack trace for each annotation.
     */
    private printManifestAnnotations;
    /**
     * Formats annotation level with icons and descriptions.
     *
     * @param level - The annotation level (INFO, WARN, ERROR).
     * @returns A string with formatted label and icon for the annotation level.
     */
    private formatAnnotationLevel;
}
