import type { Job } from "./job";
import type { Workflow } from "./workflow";
/**
 * Validates the format of an identifier.
 *
 * @param id - The identifier to validate.
 * @returns An array of error messages if the identifier is invalid, otherwise an empty array.
 */
export declare function validateIdFormat(id: string): string[];
/**
 * Validates an array of cron expressions.
 *
 * This function checks each cron expression in the provided array to determine
 * if it is valid. If an expression is invalid, an error message will be added
 * to the result array.
 *
 * @param expresiions - An array of cron expressions as strings to be validated.
 * @returns An array of error messages for any invalid cron expressions.
 */
export declare function validateCronExpression(expresiions: string[]): string[];
/**
 * Validates environment variable names and values.
 *
 * @param env - An object representing environment variables, where keys are variable names and values are their corresponding values.
 * @returns An array of error messages if there are invalid variable names or values, otherwise an empty array.
 */
export declare function validateEnvVars(env: Record<string, string | undefined>): string[];
/**
 * Validates the shell type against a list of valid shells.
 *
 * @param shell - The shell type to validate.
 * @param validShells - An array of valid shell types.
 * @returns An array of error messages if the shell type is invalid, otherwise an empty array.
 */
export declare function validateShellType(shell: string | undefined, validShells: readonly string[]): string[];
/**
 * Validates the format of the 'uses' field in a RegularStepProps.
 *
 * @param uses - The 'uses' string to validate.
 * @returns An array of error messages if the format is invalid, otherwise an empty array.
 */
export declare function validateUsesFormat(uses: string): string[];
/**
 * Validates that a job contains at least one step.
 *
 * @param job - The job to validate.
 * @returns An array of error messages if the job has no steps, otherwise an empty array.
 */
export declare function validateHasSteps(job: Job): string[];
/**
 * Validates that a workflow contains at least one job.
 *
 * @param workflow - The workflow to validate.
 * @returns An array of error messages if the workflow has no jobs, otherwise an empty array.
 */
export declare function validateHasJobs(workflow: Workflow): string[];
