import type { IConstruct } from "constructs";
import { Action, type CommonActionProps } from "../action";
/**
 * Output structure for the DockerLogin action.
 *
 * @remarks
 * This interface defines specific outputs provided by the DockerLogin action,
 * such as an output indicating the login success status.
 */
export interface DockerLoginV3Outputs {
    /**
     * Status of the login process.
     */
    readonly loginStatus: string;
}
/**
 * Configuration properties for the DockerLogin action in a GitHub Actions workflow.
 *
 * @remarks
 * `DockerLoginV3Props` defines the various options available for the DockerLogin action,
 * including registry, username, password, ECR support, and logout behavior.
 */
export interface DockerLoginV3Props extends CommonActionProps {
    /**
     * Server address of Docker registry. Defaults to Docker Hub if not provided.
     *
     * @default Docker Hub
     */
    readonly registry?: string;
    /**
     * Username for Docker registry login.
     *
     * Required for authenticated Docker registries.
     */
    readonly username?: string;
    /**
     * Password or token for Docker registry login.
     *
     * Required for authenticated Docker registries.
     */
    readonly password?: string;
    /**
     * Specifies if the registry is Amazon ECR.
     *
     * Options:
     * - "auto": Automatically detects if the registry is ECR.
     * - "true": Forces ECR login behavior.
     * - "false": Disables ECR-specific logic.
     *
     * @default "auto"
     */
    readonly ecr?: "auto" | "true" | "false";
    /**
     * Determines if the Docker registry should be logged out at the end of the job.
     *
     * @default true
     */
    readonly logout?: boolean;
    /**
     * Specifies the version of the action to use.
     */
    readonly version?: string;
}
/**
 * DockerLoginV3 action for GitHub Actions workflows, allowing login to Docker registries.
 *
 * @remarks
 * This class provides configuration for the DockerLogin action, supporting
 * registry address, credentials, ECR options, and logout settings.
 */
export declare class DockerLoginV3 extends Action {
    static readonly IDENTIFIER = "docker/login-action";
    readonly registry?: string;
    readonly username?: string;
    readonly password?: string;
    readonly ecr?: "auto" | "true" | "false";
    readonly logout?: boolean;
    /**
     * Initializes a new instance of the DockerLogin action.
     *
     * @param scope - The scope in which to define this construct.
     * @param id - Unique identifier for the action.
     * @param props - Configuration properties for the Docker login action behavior.
     */
    constructor(scope: IConstruct, id: string, props: DockerLoginV3Props);
    /**
     * Retrieves outputs of the DockerLogin action.
     *
     * @returns `DockerLoginV3Outputs` containing `loginStatus` to indicate login status.
     */
    get outputs(): DockerLoginV3Outputs;
}
