import type { IConstruct } from "constructs";
/**
 * Represents an aspect that can visit constructs in the CDK tree.
 */
export interface IAspect {
    /**
     * Visit a specific construct node.
     * @param node The construct to visit.
     */
    visit(node: IConstruct): void;
}
/**
 * Manages aspects applied to CDK construct scopes.
 * Aspects can modify constructs before they are synthesized.
 */
export declare class Aspects {
    private readonly _aspects;
    private constructor();
    /**
     * Retrieves the `Aspects` instance associated with a given construct scope.
     * If no instance exists, it creates one.
     *
     * @param scope The construct scope for which aspects will be managed.
     * @returns The `Aspects` instance for the specified scope.
     */
    static of(scope: IConstruct): Aspects;
    /**
     * Adds an aspect to be applied to this scope before synthesis.
     *
     * @param aspect The aspect to add.
     */
    add(aspect: IAspect): void;
    /**
     * Retrieves all aspects directly applied to this scope.
     *
     * @returns An array of all aspects applied.
     */
    get all(): IAspect[];
}
