import { Construct, type IConstruct } from "constructs";
/**
 * Abstract class representing a GitHub Actions CDK Component.
 *
 * @remarks
 * The `Component` class is a foundational construct for defining reusable elements in
 * GitHub Actions workflows. It extends the base `Construct` class, adding unique
 * identifiers, type metadata, and markers for internal component identification.
 */
export declare abstract class Component extends Construct {
    /**
     * Checks if an object is an instance of `Component`.
     *
     * @param x - The object to check.
     * @returns `true` if `x` is a `Component`; otherwise, `false`.
     */
    static isComponent(x: unknown): x is Component;
    /** Holds overrides for properties, allowing deep customization of component configuration. */
    protected readonly rawOverrides: Record<string, unknown>;
    /**
     * Initializes a new `Component` instance.
     *
     * @param scope - The construct scope in which this component is defined.
     * @param id - The unique identifier for this component. If not provided, an auto-generated
     * ID based on the component name and scope will be used.
     */
    constructor(scope: IConstruct, id?: string);
    /**
     * @internal
     * Synthesizes the component configuration and merges it with any overrides.
     *
     * @returns A record representing the final configuration of the component.
     */
    _synth(): Record<string, unknown>;
    /**
     * @internal
     * Internal method to return the base configuration of the component.
     *
     * Subclasses should implement this method to provide the final base configuration
     * of the component, returning a record of key-value pairs representing the component's
     * settings and properties.
     *
     * @returns A record representing the base configuration of the component.
     */
    protected abstract _toRecord(): Record<string, unknown>;
    /**
     * @internal
     * Merges two records into one, with the second record's properties
     * merging into the first in case of conflicts.
     *
     * @param base - The base record to merge from.
     * @param overrides - The record containing overrides to apply.
     * @returns The merged record.
     */
    private _mergeRecords;
    /**
     * Adds or updates an override to the component configuration at a specified path.
     *
     * @param path - Dot-separated path specifying where the override should be applied.
     * @param value - The value to set at the specified path.
     * @throws Error if the provided path is an empty or non-string value.
     */
    addOverride(path: string, value: unknown): void;
}
