import type { IConstruct } from "constructs";
import type { Manifest } from "./manifest";
import type { Workflow } from "./workflow";
/**
 * Represents a validation error message with its source.
 */
export interface ValidationErrorMessage {
    /**
     * The message describing the validation error.
     */
    readonly message: string;
    /**
     * The source construct where the error originated.
     */
    readonly source: IConstruct;
}
/**
 * Creates a validation error with a specified message and associated errors.
 *
 * @param message - The error message describing the validation issue.
 * @param errors - An array of validation error messages with their sources.
 * @returns A new Error object with additional properties for validation errors.
 */
export declare function createValidationError(message: string, errors: ValidationErrorMessage[]): Error;
/**
 * Checks if the provided error is a validation error.
 *
 * @param error - The error to check.
 * @returns A boolean indicating whether the error is a validation error.
 */
export declare function isValidationError(error: unknown): error is Error & {
    errors: ValidationErrorMessage[];
};
/**
 * Represents the session for synthesizing workflows, including output directory and validation options.
 */
export interface ISynthesisSession {
    /**
     * The output directory where synthesized YAML files will be stored.
     */
    readonly outdir: string;
    /**
     * Indicates whether to skip validation during synthesis.
     *
     * @default false
     */
    readonly skipValidation?: boolean;
    /**
     * Indicates whether to skip diff protection, ensuring workflow consistency.
     *
     * @default false
     */
    readonly skipDiffProtection?: boolean;
    /**
     * The manifest that records synthesized workflows.
     */
    readonly manifest: Manifest;
}
/**
 * Interface for synthesizers that handle workflow synthesis.
 */
export interface IWorkflowSynthesizer {
    /**
     * Synthesizes a workflow into the specified output format.
     *
     * @param session - The synthesis session containing configuration for the synthesis process.
     */
    synthesize(session: ISynthesisSession): void;
}
/**
 * Handles the synthesis of a GitHub Actions workflow, generating YAML output.
 */
export declare class WorkflowSynthesizer implements IWorkflowSynthesizer {
    protected workflow: Workflow;
    /**
     * Creates a new instance of WorkflowSynthesizer.
     *
     * @param workflow - The workflow to be synthesized.
     */
    constructor(workflow: Workflow);
    /**
     * Synthesizes the workflow into a YAML file.
     *
     * This process includes invoking aspects, validating the workflow,
     * checking annotations, and writing the output to a file.
     *
     * @param session - The synthesis session containing configuration for the synthesis process.
     * @throws {ValidationError} If validation errors are found.
     */
    synthesize(session: ISynthesisSession): void;
    /**
     * Ensures that the workflow file has not been modified during synthesis.
     *
     * @param filename - The path of the workflow YAML file.
     * @param yamlContent - The generated YAML content to compare.
     * @throws {Error} if the existing content differs from the generated content.
     */
    protected diffProtection(filename: string, yamlContent: string): void;
    /**
     * Invokes all aspects associated with the workflow.
     */
    private invokeAspects;
    /**
     * Validates the workflow, checking for any errors in the construct tree.
     *
     * @throws {ValidationError} If validation errors are found.
     */
    private validate;
    /**
     * Collects validation errors from the workflow's constructs.
     *
     * @returns An array of validation error messages along with their source constructs.
     */
    private collectValidationErrors;
    /**
     * Collects annotations from the workflow's constructs.
     *
     * @returns An array of workflow annotations.
     */
    private collectAnnotations;
}
/**
 * Invokes aspects on a construct and its children, ensuring that aspects are applied correctly.
 *
 * @param root - The root construct for which aspects should be invoked.
 */
export declare function invokeAspects(root: IConstruct): void;
